@@ -142,7 +142,7 @@ val iter : ('a -> unit) -> 'a t -> unit
 	is equivalent to [for i = 0 to length darr - 1 do f (get darr i) done;] *)
 
 val iteri : (int -> 'a -> unit) -> 'a t -> unit
-(** [iter f darr] calls the function [f] on every element of [darr].  It
+(** [iteri f darr] calls the function [f] on every element of [darr].  It
 	is equivalent to [for i = 0 to length darr - 1 do f i (get darr i) done;]
 	*)
 
@@ -170,6 +170,8 @@ val index_of : ('a -> bool) -> 'a t -> int
 (** [index_of f darr] returns the index of the first element [x] in darr such
 	as [f x] returns [true] or raise [Not_found] if not found. *)
 
+val filter : ('a -> bool) -> 'a t -> unit
+
 (** {6 Array resizers} *)
 
 type resizer_t = currslots:int -> oldlength:int -> newlength:int -> int
